==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPolyhedron.java <==
// java wrapper for vtkPolyhedron object
//

package vtk;
import vtk.*;

public class vtkPolyhedron extends vtkCell3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int RequiresInitialization_3();
  public int RequiresInitialization()
    { return RequiresInitialization_3(); }

  private native void Initialize_4();
  public void Initialize()
    { Initialize_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfFaces_7();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_7(); }

  private native long GetFace_8(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_11(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_11(id0,id1,id2); }

  private native int CellBoundary_12(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_12(id0,id1,id2); }

  private native int GetParametricCenter_13(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_13(id0); }

  private native int IsPrimaryCell_14();
  public int IsPrimaryCell()
    { return IsPrimaryCell_14(); }

  private native int RequiresExplicitFaceRepresentation_15();
  public int RequiresExplicitFaceRepresentation()
    { return RequiresExplicitFaceRepresentation_15(); }

  private native int IsInside_16(double id0[],double id1);
  public int IsInside(double id0[],double id1)
    { return IsInside_16(id0,id1); }

  private native boolean IsConvex_17();
  public boolean IsConvex()
    { return IsConvex_17(); }

  private native long GetPolyData_18();
  public vtkPolyData GetPolyData() {
    long temp = GetPolyData_18();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPolyhedron() { super(); }

  public vtkPolyhedron(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkPolyhedron.java <==
// java wrapper for vtkPolyhedron object
//

package vtk;
import vtk.*;

public class vtkPolyhedron extends vtkCell3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int RequiresInitialization_3();
  public int RequiresInitialization()
    { return RequiresInitialization_3(); }

  private native void Initialize_4();
  public void Initialize()
    { Initialize_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfFaces_7();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_7(); }

  private native long GetFace_8(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_11(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_11(id0,id1,id2); }

  private native int CellBoundary_12(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_12(id0,id1,id2); }

  private native int GetParametricCenter_13(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_13(id0); }

  private native int IsPrimaryCell_14();
  public int IsPrimaryCell()
    { return IsPrimaryCell_14(); }

  private native int RequiresExplicitFaceRepresentation_15();
  public int RequiresExplicitFaceRepresentation()
    { return RequiresExplicitFaceRepresentation_15(); }

  private native int IsInside_16(double id0[],double id1);
  public int IsInside(double id0[],double id1)
    { return IsInside_16(id0,id1); }

  private native boolean IsConvex_17();
  public boolean IsConvex()
    { return IsConvex_17(); }

  private native long GetPolyData_18();
  public vtkPolyData GetPolyData() {
    long temp = GetPolyData_18();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPolyhedron() { super(); }

  public vtkPolyhedron(long id) { super(id); }
  public native long   VTKInit();

}
